%define anolis_release 4

%bcond_with jar
%bcond_with java

Name: gettext
Version: 0.21.1
Release: %{anolis_release}%{?dist}
Summary: Gettext tools and documentation for developers and translators
License: GPLv3+ and LGPLv2+ and GFDL
URL: http://www.gnu.org/software/gettext/
Source: https://ftp.gnu.org/pub/gnu/%{name}/%{name}-%{version}.tar.xz
Source2: msghack.py
Source3: msghack.1

BuildRequires: automake libtool gcc-c++
%if %{with java}
BuildRequires: gcc-java, libgcj
BuildRequires: java-1.6.0-openjdk-devel
%if %{with jar}
BuildRequires: %{_bindir}/fastjar zip, unzip
%endif
%endif
BuildRequires: emacs git xz
BuildRequires: teckit texlive-dvips texlive-dvipdfmx texinfo-tex texlive-xetex
BuildRequires: ncurses-devel libxml2-devel glib2-devel libacl-devel libunistring-devel
BuildRequires: glibc-langpack-de glibc-langpack-en glibc-langpack-fa glibc-langpack-fr
BuildRequires: glibc-langpack-ja glibc-langpack-tr glibc-langpack-zh
Provides: bundled(gnulib) bundled(libcroco) = 0.6.12
Requires: %{name}-runtime = %{version}-%{release} %{name}-libs = %{version}-%{release}

Patch1: %{name}-%{version}-disable-libtextstyle.patch
Patch2: %{name}-%{version}-covscan.patch
Patch3: %{name}-java17-2062407.patch

# Disable gnulib test-execute.sh test, as it always fail on koji/an23
Patch101: %{name}-0.21.1-disable-gnulib-test-execute-sh.patch

%description
The GNU %{name} package provides a set of tools and documentation for
producing multi-lingual messages in programs. Tools include a set of
conventions about how programs should be written to support message
catalogs, a directory and file naming organization for the message
catalogs, a runtime library which supports the retrieval of translated
messages, and stand-alone programs for handling the translatable and
the already translated strings. Gettext provides an easy to use
library and tools for creating, using, and modifying natural language
catalogs and is a powerful and simple method for internationalizing
programs.

%package libs
Summary: Libraries for %{name}
License: LGPLv2+ and GPLv3+
Obsoletes: libtextstyle < %{version}-%{release}

%description libs
This package contains libraries used internationalization support.

%package devel
Summary: Development files for %{name}
License: LGPLv2+ and GPLv3+ and GFDL
Requires: %{name} = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}
Requires: %{name}-common-devel = %{version}-%{release}
Requires: xz diffutils
Obsoletes: %{name}-autopoint < 0.18.1.1-3
Obsoletes: libtextstyle-devel < %{version}-%{release}
Provides: %{name}-autopoint = %{version}-%{release}

%description devel
This package contains all development related files necessary for
developing or compiling applications/libraries that needs
internationalization capability. You also need this package if you
want to add %{name} support for your project.

%package common-devel
Summary: Common development files for %{name}
License: GPLv3+
BuildArch: noarch

%description common-devel
This package contains common architecture independent %{name} development files.

%package envsubst
Summary: Substitutes the values of environment variables
Conflicts: %{name} < 0.21.1
 
%description envsubst
Substitutes the values of environment variables.

%package -n emacs-%{name}
Summary: Support for editing po files within GNU Emacs
BuildArch: noarch
Requires: emacs(bin) >= %{_emacs_version}
Provides: emacs-%{name}-el = %{version}-%{release} emacs-po-mode
Obsoletes: emacs-%{name}-el < %{version}-%{release}

%description -n emacs-%{name}
This package provides a major mode for editing po files within GNU Emacs.

%package -n msghack
Summary: Alter PO files in ways
BuildArch: noarch

%description -n msghack
This program can be used to alter .po files in ways no sane mind would
think about.

%package runtime
Summary: GNU runtime libraries and programs for producing multi-lingual messages
License: GPLv3+ and LGPLv2+
Requires: %{name}-libs = %{version}-%{release}
Requires: %{name}-envsubst = %{version}-%{release}
Conflicts: %{name} < 0.21.1

%description runtime
The GNU %{name}-runtime package provides an easy to use runtime libraries and
programs for creating, using, and modifying natural language catalogs
and is a powerful and simple method for internationalizing programs.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n %{name}-%{version} -p1

%build
autoreconf -fi

sed -e 's/\(gl_cv_libxml_force_included=\)yes/\1no/' \
    -i libtextstyle/configure

%if %{with java}
export JAVAC=gcj
%if %{with jar}
export JAR=fastjar
%endif
%endif

export CPPFLAGS="-I%{_includedir}/libxml2"
export LIBS="-lxml2"
%configure --enable-nls --disable-static \
    --enable-shared --disable-csharp --disable-rpath \
%if %{with java}
    --enable-java \
%else
    --disable-java --disable-native-java \
%endif
    --with-xz

sed -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    -e 's|CC=.g..|& -Wl,--as-needed|' \
    -i $(find . -name libtool)

%make_build %{?with_java:GCJFLAGS="-findirect-dispatch"}

%install
%make_install \
    lispdir=%{_datadir}/emacs/site-lisp/%{name} \
    aclocaldir=%{_datadir}/aclocal EXAMPLESFILES=""

install -pm 755 %SOURCE2 %{buildroot}/%{_bindir}/msghack
install -pm 644 %SOURCE3 %{buildroot}/%{_mandir}/man1/msghack.1

chmod 755 %{buildroot}%{_libdir}/preloadable_libintl.so

for i in %{name}-runtime/man/*.html; do
  rm %{buildroot}%{_datadir}/doc/%{name}/`basename $i`
done
rm -r %{buildroot}%{_datadir}/doc/%{name}/javadoc*

rm -rf %{buildroot}%{_datadir}/doc/%{name}/examples

rm -rf htmldoc
mkdir htmldoc
mv %{buildroot}%{_datadir}/doc/%{name}/* %{buildroot}/%{_datadir}/doc/libasprintf/* htmldoc
rm -r %{buildroot}%{_datadir}/doc/libasprintf
rm -r %{buildroot}%{_datadir}/doc/%{name}

%if %{with jar}
rm -f %{buildroot}%{_datadir}/%{name}/libintl.jar
%endif

rm -f %{buildroot}%{_datadir}/%{name}/%{name}.jar

# own this directory for third-party *.its files
mkdir -p %{buildroot}%{_datadir}/%{name}/its

rm %{buildroot}%{_libdir}/libgettext{src,lib}.so

install -d %{buildroot}%{_emacs_sitestartdir}
mv %{buildroot}%{_emacs_sitelispdir}/%{name}/start-po.el %{buildroot}%{_emacs_sitestartdir}
rm %{buildroot}%{_emacs_sitelispdir}/%{name}/start-po.elc

%find_lang %{name}-runtime
%find_lang %{name}-tools

%generate_compatibility_deps

%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}:$PWD/%{name}-tools/intl/.libs
 
make check LIBUNISTRING=-lunistring

%files -f %{name}-tools.lang
%license COPYING
%doc %{name}-tools/misc/DISCLAIM
%doc %{name}-tools/man/msg*.1.html
%doc %{name}-tools/man/recode*.1.html
%doc %{name}-tools/man/xgettext.1.html
%doc %{name}-tools/doc/FAQ.html
%doc %{name}-tools/doc/tutorial.html
%{abidir}/msgattrib-option.list
%{abidir}/msgcat-option.list
%{abidir}/msgcmp-option.list
%{abidir}/msgcomm-option.list
%{abidir}/msgconv-option.list
%{abidir}/msgen-option.list
%{abidir}/msgexec-option.list
%{abidir}/msgfilter-option.list
%{abidir}/msgfmt-option.list
%{abidir}/msggrep-option.list
%{abidir}/msginit-option.list
%{abidir}/msgmerge-option.list
%{abidir}/msgunfmt-option.list
%{abidir}/msguniq-option.list
%{abidir}/recode-sr-latin-option.list
%{abidir}/xgettext-option.list
%{_bindir}/msgattrib
%{_bindir}/msgcat
%{_bindir}/msgcmp
%{_bindir}/msgcomm
%{_bindir}/msgconv
%{_bindir}/msgen
%{_bindir}/msgexec
%{_bindir}/msgfilter
%{_bindir}/msgfmt
%{_bindir}/msggrep
%{_bindir}/msginit
%{_bindir}/msgmerge
%{_bindir}/msgunfmt
%{_bindir}/msguniq
%{_bindir}/recode-sr-latin
%{_bindir}/xgettext
%{_infodir}/gettext*
%{_mandir}/man1/msgattrib.1*
%{_mandir}/man1/msgcat.1*
%{_mandir}/man1/msgcmp.1*
%{_mandir}/man1/msgcomm.1*
%{_mandir}/man1/msgconv.1*
%{_mandir}/man1/msgen.1*
%{_mandir}/man1/msgexec.1*
%{_mandir}/man1/msgfilter.1*
%{_mandir}/man1/msgfmt.1*
%{_mandir}/man1/msggrep.1*
%{_mandir}/man1/msginit.1*
%{_mandir}/man1/msgmerge.1*
%{_mandir}/man1/msgunfmt.1*
%{_mandir}/man1/msguniq.1*
%{_mandir}/man1/recode-sr-latin.1*
%{_mandir}/man1/xgettext.1*
%{_libdir}/%{name}
%if %{with java}
%exclude %{_libdir}/%{name}/gnu.%{name}.*
%endif
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/its
%{_datadir}/%{name}/ABOUT-NLS
%{_datadir}/%{name}/po
%{_datadir}/%{name}/styles
%dir %{_datadir}/%{name}-%{version}
%{_datadir}/%{name}-%{version}/its

%files libs
%dir %{abidir}
%{abidir}/libasprintf.dump
%{abidir}/libgettextpo.dump
%{abidir}/libgettextlib-0.*.dump
%{abidir}/libgettextsrc-0.*.dump
%{_libdir}/libasprintf.so.0*
%{_libdir}/libgettextpo.so.0*
%{_libdir}/libgettextlib-0.*.so
%{_libdir}/libgettextsrc-0.*.so
%if %{with jar}
%{_datadir}/%{name}/libintl.jar
%endif

%files devel
%doc %{name}-runtime/intl-java/javadoc*
%doc %{name}-runtime/man/*.3.html ChangeLog
%doc %{name}-tools/man/autopoint.1.html
%doc %{name}-tools/man/gettextize.1.html
%{abidir}/autopoint-option.list
%{abidir}/gettextize-option.list
%{abidir}/preloadable_libintl.dump
%{_bindir}/autopoint
%{_bindir}/gettextize
%{_datadir}/aclocal/*
%{_datadir}/%{name}/projects/
%{_datadir}/%{name}/config.rpath
%{_datadir}/%{name}/*.h
%{_datadir}/%{name}/msgunfmt.tcl
%{_datadir}/%{name}/javaversion.class
%{_includedir}/autosprintf.h
%{_includedir}/%{name}-po.h
%{_infodir}/autosprintf*
%{_libdir}/libasprintf.so
%{_libdir}/libgettextpo.so
%{_libdir}/preloadable_libintl.so
%{_mandir}/man1/autopoint.1*
%{_mandir}/man1/gettextize.1*
%{_mandir}/man3/*
%if %{with java}
%{_libdir}/%{name}/gnu.%{name}.*
%endif

%files common-devel
%{_datadir}/%{name}/archive.*.tar.xz

%files envsubst
%license COPYING
%doc %{name}-runtime/man/envsubst.1.html
%{_bindir}/envsubst
%{abidir}/envsubst-option.list
%{_mandir}/man1/envsubst.1*

%files -n emacs-%{name}
%dir %{_emacs_sitelispdir}/%{name}
%{_emacs_sitelispdir}/%{name}/*.elc
%{_emacs_sitelispdir}/%{name}/*.el
%{_emacs_sitestartdir}/*.el

%files -n msghack
%license COPYING
%{_bindir}/msghack
%{_mandir}/man1/msghack.1*

%files runtime -f %{name}-runtime.lang
%license COPYING
%doc %{name}-runtime/BUGS
%doc %{name}-runtime/man/%{name}.1.html
%doc %{name}-runtime/man/ngettext.1.html
%doc %{name}-runtime/intl/COPYING*
%{abidir}/%{name}-option.list
%{abidir}/%{name}.sh-option.list
%{abidir}/ngettext-option.list
%{_bindir}/%{name}
%{_bindir}/%{name}.sh
%{_bindir}/ngettext
%{_mandir}/man1/%{name}.1*
%{_mandir}/man1/ngettext.1*

%files doc
%doc AUTHORS %{name}-runtime/BUGS README NEWS THANKS

%changelog
* Sat Apr 15 2023 Jing Zhang <renyu.zj@linux.alibaba.com> - 0.21.1-4
- Refact spec

* Thu Mar 23 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 0.21.1-3
- Bump version to rebuild

* Mon Dec 19 2022 Funda Wang <fundawang@yeah.net> - 0.21.1-2
- Fix versioned conflicts

* Thu Nov 24 2022 Funda Wang <fundawang@yeah.net> - 0.21.1-1
- New version 0.21.1
- Remove gnulib test-execute.sh test as it failed always for an23

* Thu Nov 24 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 0.21-4
- rebuild with libunistring update

* Thu Oct 27 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.21-3
- optimise spec file

* Thu Sep 29 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.21-2
- add doc package

* Wed Mar 09 2022 Hongwei Qin <qhw01063182@alibaba-inc.com> - 0.21-1
- gettext-0.21 is available 
- Init for Anolis OS 23
